==> ldap-account-manager_5.2.orig.tar.bz2: ldap-account-manager-5.2/templates/lib/extra/ckeditor/plugins/link/lang/lt.js <==
﻿/*
Copyright (c) 2003-2014, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'link', 'lt', {
	acccessKey: 'Prieigos raktas',
	advanced: 'Papildomas',
	advisoryContentType: 'Konsultacinio turinio tipas',
	advisoryTitle: 'Konsultacinė antraštė',
	anchor: {
		toolbar: 'Įterpti/modifikuoti žymę',
		menu: 'Žymės savybės',
		title: 'Žymės savybės',
		name: 'Žymės vardas',
		errorName: 'Prašome įvesti žymės vardą',
		remove: 'Pašalinti žymę'
	},
	anchorId: 'Pagal žymės Id',
	anchorName: 'Pagal žymės vardą',
	charset: 'Susietų išteklių simbolių lentelė',
	cssClasses: 'Stilių lentelės klasės',
	emailAddress: 'El.pašto adresas',
	emailBody: 'Žinutės turinys',
	emailSubject: 'Žinutės tema',
	id: 'Id',
	info: 'Nuorodos informacija',
	langCode: 'Teksto kryptis',
	langDir: 'Teksto kryptis',
	langDirLTR: 'Iš kairės į dešinę (LTR)',
	langDirRTL: 'Iš dešinės į kairę (RTL)',
	menu: 'Taisyti nuorodą',
	name: 'Vardas',
	noAnchors: '(Šiame dokumente žymių nėra)',
	noEmail: 'Prašome įvesti el.pašto adresą',
	noUrl: 'Prašome įvesti nuorodos URL',
	other: '<kitas>',
	popupDependent: 'Priklausomas (Netscape)',
	popupFeatures: 'Išskleidžiamo lango savybės',
	popupFullScreen: 'Visas ekranas (IE)',
	popupLeft: 'Kairė pozicija',
	popupLocationBar: 'Adreso juosta',
	popupMenuBar: 'Meniu juosta',
	popupResizable: 'Kintamas dydis',
	popupScrollBars: 'Slinkties juostos',
	popupStatusBar: 'Būsenos juosta',
	popupToolbar: 'Mygtukų juosta',
	popupTop: 'Viršutinė pozicija',
	rel: 'Sąsajos',
	selectAnchor: 'Pasirinkite žymę',
	styles: 'Stilius',
	tabIndex: 'Tabuliavimo indeksas',
	target: 'Paskirties vieta',
	targetFrame: '<kadras>',
	targetFrameName: 'Paskirties kadro vardas',
	targetPopup: '<išskleidžiamas langas>',
	targetPopupName: 'Paskirties lango vardas',
	title: 'Nuoroda',
	toAnchor: 'Žymė šiame puslapyje',
	toEmail: 'El.paštas',
	toUrl: 'Nuoroda',
	toolbar: 'Įterpti/taisyti nuorodą',
	type: 'Nuorodos tipas',
	unlink: 'Panaikinti nuorodą',
	upload: 'Siųsti'
} );

==> ldap-account-manager_8.5.orig.tar.bz2: ldap-account-manager-8.5/templates/lib/extra/ckeditor/plugins/link/lang/lt.js <==
﻿/*
Copyright (c) 2003-2023, CKSource Holding sp. z o.o. All rights reserved.
CKEditor 4 LTS ("Long Term Support") is available under the terms of the Extended Support Model.
*/
CKEDITOR.plugins.setLang( 'link', 'lt', {
	acccessKey: 'Prieigos raktas',
	advanced: 'Papildomas',
	advisoryContentType: 'Konsultacinio turinio tipas',
	advisoryTitle: 'Konsultacinė antraštė',
	anchor: {
		toolbar: 'Įterpti/modifikuoti žymę',
		menu: 'Žymės savybės',
		title: 'Žymės savybės',
		name: 'Žymės vardas',
		errorName: 'Prašome įvesti žymės vardą',
		errorWhitespace: 'Anchor name cannot contain space characters', // MISSING
		remove: 'Pašalinti žymę'
	},
	anchorId: 'Pagal žymės Id',
	anchorName: 'Pagal žymės vardą',
	charset: 'Susietų išteklių simbolių lentelė',
	cssClasses: 'Stilių lentelės klasės',
	download: 'Force Download', // MISSING
	displayText: 'Display Text', // MISSING
	emailAddress: 'El.pašto adresas',
	emailBody: 'Žinutės turinys',
	emailSubject: 'Žinutės tema',
	id: 'Id',
	info: 'Nuorodos informacija',
	langCode: 'Teksto kryptis',
	langDir: 'Teksto kryptis',
	langDirLTR: 'Iš kairės į dešinę (LTR)',
	langDirRTL: 'Iš dešinės į kairę (RTL)',
	menu: 'Taisyti nuorodą',
	name: 'Vardas',
	noAnchors: '(Šiame dokumente žymių nėra)',
	noEmail: 'Prašome įvesti el.pašto adresą',
	noUrl: 'Prašome įvesti nuorodos URL',
	noTel: 'Please type the phone number', // MISSING
	other: '<kitas>',
	phoneNumber: 'Phone number', // MISSING
	popupDependent: 'Priklausomas (Netscape)',
	popupFeatures: 'Išskleidžiamo lango savybės',
	popupFullScreen: 'Visas ekranas (IE)',
	popupLeft: 'Kairė pozicija',
	popupLocationBar: 'Adreso juosta',
	popupMenuBar: 'Meniu juosta',
	popupResizable: 'Kintamas dydis',
	popupScrollBars: 'Slinkties juostos',
	popupStatusBar: 'Būsenos juosta',
	popupToolbar: 'Mygtukų juosta',
	popupTop: 'Viršutinė pozicija',
	rel: 'Sąsajos',
	selectAnchor: 'Pasirinkite žymę',
	styles: 'Stilius',
	tabIndex: 'Tabuliavimo indeksas',
	target: 'Paskirties vieta',
	targetFrame: '<kadras>',
	targetFrameName: 'Paskirties kadro vardas',
	targetPopup: '<išskleidžiamas langas>',
	targetPopupName: 'Paskirties lango vardas',
	title: 'Nuoroda',
	toAnchor: 'Žymė šiame puslapyje',
	toEmail: 'El.paštas',
	toUrl: 'Nuoroda',
	toPhone: 'Phone', // MISSING
	toolbar: 'Įterpti/taisyti nuorodą',
	type: 'Nuorodos tipas',
	unlink: 'Panaikinti nuorodą',
	upload: 'Siųsti'
} );
